
# pyodbc

pyodbc makes it easy to connect to databases using ODBC.  It implements the DB
API 2.0 specification, but adds even more convenience.

The library is designed to be stand-alone.  It does not have other dependencies
and only uses Python's built-in data types.

To install, use pip or setuptools::

    pip install pyodbc

[Documentation](http://mkleehammer.github.io/pyodbc)
